diff --git a/sohstationviewer/view/main_window.py b/sohstationviewer/view/main_window.py
index 7122e99abecf5fdab1db492a7def7360bc97983b..dcb232f3860b22956b77fae2b697602e0cdc035b 100755
--- a/sohstationviewer/view/main_window.py
+++ b/sohstationviewer/view/main_window.py
@@ -160,7 +160,6 @@ class MainWindow(QtWidgets.QMainWindow, UIMainWindow):
         """
         self.bit_weight_opt: str = ''  # currently only need one option
         self.get_channel_prefer()
-        self.yyyy_mm_dd_action.triggered.emit()
 
         """
         waveform_dlg: widget to display waveform channels' plotting
@@ -196,6 +195,7 @@ class MainWindow(QtWidgets.QMainWindow, UIMainWindow):
         self.read_config()
         self.validate_config()
         self.apply_config()
+        self.yyyy_mm_dd_action.trigger()
 
     @QtCore.Slot()
     def save_plot(self):
@@ -364,6 +364,8 @@ class MainWindow(QtWidgets.QMainWindow, UIMainWindow):
         self.time_to_date_edit.setDisplayFormat(qt_format)
         self.time_from_date_edit.setDisplayFormat(qt_format)
         self.date_format = display_format
+        self.tps_dlg.date_format = self.date_format
+        self.waveform_dlg.date_format = self.date_format
 
     @QtCore.Slot()
     def open_files_list_item_double_clicked(self, item: FileListItem):
@@ -822,7 +824,8 @@ class MainWindow(QtWidgets.QMainWindow, UIMainWindow):
             self.is_plotting_tps = True
             peer_plotting_widgets.append(self.tps_dlg.plotting_widget)
             self.tps_dlg.set_data(
-                self.data_type, ','.join([str(d) for d in self.dir_names]))
+                self.data_type,
+                ','.join([str(d) for d in self.dir_names]))
             self.tps_dlg.show()
             # The waveform and TPS plots is being stopped at the same time, so
             # we can't simply reset all flags. Instead, we use an intermediate
@@ -843,7 +846,8 @@ class MainWindow(QtWidgets.QMainWindow, UIMainWindow):
             # waveformPlot
             peer_plotting_widgets.append(self.waveform_dlg.plotting_widget)
             self.waveform_dlg.set_data(
-                self.data_type, ','.join([str(d) for d in self.dir_names]))
+                self.data_type,
+                ','.join([str(d) for d in self.dir_names]))
             self.waveform_dlg.show()
             waveform_widget = self.waveform_dlg.plotting_widget
             waveform_widget.stopped.connect(self.reset_is_plotting_waveform)
diff --git a/sohstationviewer/view/plotting/plotting_widget/plotting.py b/sohstationviewer/view/plotting/plotting_widget/plotting.py
index 7b44ad3f3b1d19c1500a0f8912b95895b8546d24..1a169ac683cf9f2627f65f06bfc4b6cb6a07130b 100644
--- a/sohstationviewer/view/plotting/plotting_widget/plotting.py
+++ b/sohstationviewer/view/plotting/plotting_widget/plotting.py
@@ -269,13 +269,14 @@ class Plotting:
                 obj, c = cStr.split(':')
                 colors[obj] = c
         l_color = 'G'
-        d_color = 'W'
         has_dot = False
         if 'L' in colors:
             l_color = colors['L']
         if 'D' in colors:
             d_color = colors['D']
             has_dot = True
+        else:
+            d_color = l_color
 
         if chan_id == 'GPS Lk/Unlk':
             sample_no_list = []
@@ -291,7 +292,7 @@ class Plotting:
             info=info, y_list=y_list, linked_ax=linked_ax)
 
         for x, y in zip(x_list, y_list):
-            if not has_dot:
+            if not has_dot and sample_no_list[0] > 1:
                 # set marker to be able to click point for info
                 # but marker's size is small to not show dot.
                 ax.myPlot = ax.plot(x, y, marker='o', markersize=0.01,
diff --git a/sohstationviewer/view/plotting/plotting_widget/plotting_widget.py b/sohstationviewer/view/plotting/plotting_widget/plotting_widget.py
index 69875c505765e7cd03625148e2016a271597cb3a..cfcfb8a0c63b1837becc4adebd15c423d6625eda 100755
--- a/sohstationviewer/view/plotting/plotting_widget/plotting_widget.py
+++ b/sohstationviewer/view/plotting/plotting_widget/plotting_widget.py
@@ -586,12 +586,13 @@ class PlottingWidget(QtWidgets.QScrollArea):
                     if tr_min_ys != []:
                         new_min_y = min(tr_min_ys)
                         new_max_y = max(tr_max_ys)
+                        # in case total_points == 1, y lim shouldn't be set
+                        # again or the plot would be collapsed to one line
+                        if total_points > 1:
+                            self.plotting_axes.set_axes_ylim(
+                                ax, new_min_y, new_max_y)
                     ax.center_total_point_lbl.set_text(total_points)
 
-                if new_min_y is not None:
-                    self.plotting_axes.set_axes_ylim(
-                        ax, new_min_y, new_max_y, ax.chan_db_info)
-
     def draw(self):
         """
         Update drawing on the widget.
diff --git a/sohstationviewer/view/plotting/waveform_dialog.py b/sohstationviewer/view/plotting/waveform_dialog.py
index 19ff27ad7213d0c739c3fe67f83ac7eb493fdd62..24c9a9a8cfb2256c3f40f1a7ef7bbe7776f4305d 100755
--- a/sohstationviewer/view/plotting/waveform_dialog.py
+++ b/sohstationviewer/view/plotting/waveform_dialog.py
@@ -74,6 +74,10 @@ class WaveformDialog(QtWidgets.QWidget):
         data_type: str - type of data being plotted
         """
         self.data_type = None
+        """
+         date_format: format for date
+        """
+        self.date_format: str = 'YYYY-MM-DD'
         self.setGeometry(50, 10, 1600, 700)
         self.setWindowTitle("Raw Data Plot")
 
@@ -107,12 +111,12 @@ class WaveformDialog(QtWidgets.QWidget):
         self.info_text_browser.setFixedHeight(60)
         bottom_layout.addWidget(self.info_text_browser)
 
-    def set_data(self, data_type, folder_name):
+    def set_data(self, data_type: str, folder_name: str):
         """
         Set data_type and the window's title.
 
-        :param data_type: str - data type of data being plotted
-        :param folder_name: str - name of the folder of the data set to be
+        :param data_type: data type of data being plotted
+        :param folder_name: name of the folder of the data set to be
             displayed
         """
         self.data_type = data_type
diff --git a/sohstationviewer/view/ui/main_ui.py b/sohstationviewer/view/ui/main_ui.py
index 194b23483bc13cbd916c0d77a737d556eee6a313..4c98291a6cc6a45533b847dc17f65cb2f97544ac 100755
--- a/sohstationviewer/view/ui/main_ui.py
+++ b/sohstationviewer/view/ui/main_ui.py
@@ -721,7 +721,6 @@ class UIMainWindow(object):
             lambda: main_window.set_date_format('YYYYMMMDD'))
         self.yyyy_doy_action.triggered.connect(
             lambda: main_window.set_date_format('YYYY:DOY'))
-        self.yyyy_mm_dd_action.trigger()
 
         # Database
         self.add_edit_data_type_action.triggered.connect(
diff --git a/sohstationviewer/view/util/functions.py b/sohstationviewer/view/util/functions.py
index 58e3faab6a4945964b1f8094712631ebc74479ef..1a70f2fac011c174cbf8113c06ae8b33aae06f2f 100644
--- a/sohstationviewer/view/util/functions.py
+++ b/sohstationviewer/view/util/functions.py
@@ -254,12 +254,8 @@ def get_total_miny_maxy(
     if new_x.size == 0:
         return 0, None, None
 
-    new_min_x = min(new_x)
-    new_max_x = max(new_x)
-
-    new_min_x_index = np.where(x == new_min_x)[0][0]
-    new_max_x_index = np.where(x == new_max_x)[0][0]
-
+    new_min_x_index = min(new_x_indexes)
+    new_max_x_index = max(new_x_indexes)
     new_y = y[new_min_x_index:new_max_x_index + 1]
     new_min_y = min(new_y)
     new_max_y = max(new_y)
diff --git a/sohstationviewer/view/plotting/time_power_squared_dialog.py b/sohstationviewer/view/plotting/time_power_squared_dialog.py
index f27f3c4362b8d0cf30d521808810b3da6fc5856d..5e533b53b591894908a59bca12eb8899c5dde0d3 100755
--- a/sohstationviewer/view/plotting/time_power_squared_dialog.py
+++ b/sohstationviewer/view/plotting/time_power_squared_dialog.py
@@ -498,6 +498,11 @@ class TimePowerSquaredDialog(QtWidgets.QWidget):
         data_type: str - type of data being plotted
         """
         self.data_type = None
+        """
+         date_format: format for date
+        """
+        self.date_format: str = 'YYYY-MM-DD'
+
         self.setGeometry(50, 50, 1200, 700)
         self.setWindowTitle("TPS Plot")
 
@@ -577,16 +582,16 @@ class TimePowerSquaredDialog(QtWidgets.QWidget):
         self.connect_signals()
         self.color_range_changed()
 
-    def set_data(self, data_type, file_name):
+    def set_data(self, data_type: str, folder_name: str):
         """
         Set data_type and the window's title.
 
         :param data_type: str - data type of data being plotted
         :param file_name: str - name of the file/folder of the data set to be
             displayed
         """
         self.data_type = data_type
-        self.setWindowTitle("TPS Plot %s - %s" % (data_type, file_name))
+        self.setWindowTitle("TPS Plot %s - %s" % (data_type, folder_name))
 
     def resizeEvent(self, event):
         """
@@ -577,16 +582,16 @@ class TimePowerSquaredDialog(QtWidgets.QWidget):
         Set data_type and the window's title.
 
-        :param data_type: str - data type of data being plotted
-        :param file_name: str - name of the file/folder of the data set to be
+        :param data_type: data type of data being plotted
+        :param folder_name: name of the folder of the data set to be
             displayed
         """